function love.load()
	-- Sky color
    love.graphics.setBackgroundColor( 58, 106, 127 )
    -- Pixel art filter
    love.graphics.setDefaultImageFilter("nearest", "nearest")

    -- Object images
    stage = {}
    stage.idle = love.graphics.newImage("images/stage/stage.png")
    stage.x = 54
    stage.y = 400
    stage.width = 404
    stage.height = 256

    water = love.graphics.newImage("images/water/water.png")

    -- Sumo Table
    sumo = {}
    sumo.x = 300
    sumo.y = 298
    sumo.width = 18
    sumo.height = 28
    sumo.speed = 150
    
    sumo.idle = {
    	love.graphics.newImage("images/sumo/idle/idle1.png"),
    	love.graphics.newImage("images/sumo/idle/idle2.png")
	}
	sumo.walk = {
    	love.graphics.newImage("images/sumo/walk/walk1.png"),
    	love.graphics.newImage("images/sumo/walk/walk2.png")
	}
	sumo.push = {
    	love.graphics.newImage("images/sumo/push/push1.png"),
    	love.graphics.newImage("images/sumo/push/push2.png")
	}


	-- Physics Setup
	-- Sets 32px to be a meter in the physics engine
	love.physics.setMeter(32)
	-- Create a world with standard gravity 
	world = love.physics.newWorld(0, 9.81 * 32, true)

	-- Create a ground body at (0,0) static
	ground = love.physics.newBody(world,0,0,"static")
	-- Create the ground shape at (X,Y) with size (SX,SY)
	ground_shape = love.physics.newRectangleShape( stage.x+(stage.width/2), stage.y+(stage.height/2), stage.width, stage.height)
	-- Create fixture between body and shape
	ground_fixture = love.physics.newFixture(ground, ground_shape)

	-- Create a Body for the sumo
	body = love.physics.newBody(world, 0, 0, "dynamic")
	-- Attach shape to the body
	rectangle_shape = love.physics.newRectangleShape(body:getX(),body:getY(),sumo.width*2,sumo.height*2)
	-- Create fixture between body and shape
    fixture = love.physics.newFixture( body, rectangle_shape)
	-- Calculate the mass of the body based on attatched shapes.
	-- This gives realistic simulations.
	body:setMassData(rectangle_shape:computeMass( 1 ))

end

function love.update(dt)
	
	sumo.x = body:getX()
	sumo.y = body:getY()

	-- Update the world.
	world:update(dt)
	moveSumo(dt)
end

function love.draw()
    -- Draws the Sumo
    love.graphics.draw( sumo.idle[1], sumo.x-sumo.width, sumo.y-sumo.height, 0, 2, 2, 0, 0, 0, 0 )
    
    -- Draws the ground
    love.graphics.draw( stage.idle, stage.x, stage.y, 0, 4, 4, 0, 0, 0, 0 )

	-- Draws the water
    love.graphics.draw( water, 48, 585, 0, 4, 4, 0, 0, 0, 0 )
    
end

function moveSumo(dt)
	if love.keyboard.isDown("left") then
        currX = body:getX() - sumo.speed*dt
        body:setPosition(currX,body:getY())
    elseif love.keyboard.isDown("right") then
        currX = body:getX() + sumo.speed*dt
        body:setPosition(currX, body:getY())
    end
end
